@@ -135,6 +135,14 @@ impl Kubectl {
         })
     }
 
+    pub(crate) fn with_context_or_current(context: Option<&str>) -> anyhow::Result<Self> {
+        if let Some(context) = context {
+            Self::with_context(context)
+        } else {
+            Self::new()
+        }
+    }
+
     pub(crate) fn context(&self) -> &str {
         &self.context
     }
