@@ -522,6 +522,8 @@ enum Command {
         setting(clap::AppSettings::Hidden),
     )]
     ListRegions {
+        #[structopt(help = "Kubeconfig context to use", long, short, visible_alias = "ctx")]
+        context: Option<String>,
         #[structopt(help = "Also list zones", long, short)]
         zone: bool,
     },
@@ -764,7 +766,7 @@ impl Cli {
             Command::ListNamespaces => statehub.list_namespaces().await,
             Command::ListNodes => statehub.list_nodes().await,
             Command::ListPods => statehub.list_pods().await,
-            Command::ListRegions { zone } => statehub.list_regions(zone).await,
+            Command::ListRegions { context, zone } => statehub.list_regions(context, zone).await,
             Command::SaveConfig => statehub.save_config().await,
             Command::SelfUpdate => statehub.self_update().await,
         }
@@ -1234,8 +1236,8 @@ impl StateHub {
         Ok(())
     }
 
-    async fn list_regions(&self, zone: bool) -> anyhow::Result<()> {
-        k8s::Kubectl::new()?
+    async fn list_regions(&self, context: Option<String>, zone: bool) -> anyhow::Result<()> {
+        k8s::Kubectl::with_context_or_current(context.as_deref())?
             .get_regions(zone)
             .await
             .map(|map| {
