@@ -110,7 +110,8 @@ impl StateHub {
                 .await?;
         }
 
-        self.helm_install_helper(&cluster, register_cluster).await?;
+        self.helm_install_helper(&kubectl, &cluster, register_cluster)
+            .await?;
 
         cluster.print(&self.stdout, self.json)
     }
@@ -430,12 +431,15 @@ or run following commands before running 'statehub register-cluster`
 
     pub(super) async fn helm_install_helper(
         &self,
+        kubectl: &k8s::Kubectl,
         cluster: &v0::Cluster,
         register_cluster: &RegisterCluster,
     ) -> anyhow::Result<()> {
+        let kube_context = kubectl.context();
+        let namespace = &register_cluster.namespace;
         let (stdout, stderr) = register_cluster
             .helm
-            .execute(cluster, &register_cluster.namespace)
+            .execute(cluster, kube_context, namespace)
             .await?;
 
         self.verbosely(stdout)?;
