@@ -15,7 +15,7 @@ use serde::{Deserialize, Serialize};
 use serde_with::{skip_serializing_none, DeserializeFromStr, SerializeDisplay};
 use uuid::Uuid;
 
-use crate::location::{InvalidRegion, Location};
+use crate::location::{InvalidLocation, Location};
 use crate::traits::{CloudRegion, Show};
 
 pub use self::aws::{AwsRegion, PrivateLinkServiceAws};
